@@ -34,6 +34,69 @@
 //! - [`GlobalCredentialProvider`] : 使用全局变量配置的认证信息
 //! - [`EnvCredentialProvider`] : 使用环境变量配置的认证信息
 //! - [`ChainCredentialsProvider`] : 配置多个 [`CredentialProvider`] 形成认证信息串，遍历找寻第一个可用的认证信息
+//!
+//! ### 代码示例
+//!
+//! #### 计算七牛鉴权签名 V1
+//!
+//! ```
+//! use qiniu_credential::{Credential, HeaderValue, prelude::*};
+//! use mime::APPLICATION_WWW_FORM_URLENCODED;
+//! use std::io::Cursor;
+//!
+//! # fn main() -> anyhow::Result<()> {
+//! let credential = Credential::new("abcdefghklmnopq", "1234567890");
+//! let authorization = credential
+//!     .get(Default::default())?
+//!     .authorization_v1_for_request(
+//!         &"http://upload.qiniup.com/".parse()?,
+//!         Some(&HeaderValue::from_str(APPLICATION_WWW_FORM_URLENCODED.as_ref())?),
+//!         b"name=test&language=go"
+//!     );
+//! # Ok(())
+//! # }
+//! ```
+//!
+//! #### 计算七牛鉴权签名 V2
+//!
+//! ```
+//! use qiniu_credential::{Credential, Method, HeaderMap, HeaderValue, prelude::*};
+//! use http::header::CONTENT_TYPE;
+//! use mime::APPLICATION_JSON;
+//! # fn main() -> anyhow::Result<()> {
+//! let credential = Credential::new("abcdefghklmnopq", "1234567890");
+//! let mut headers = HeaderMap::new();
+//! headers.insert(CONTENT_TYPE, HeaderValue::from_str(APPLICATION_JSON.as_ref())?);
+//! let authorization = credential
+//!     .get(Default::default())?
+//!     .authorization_v2_for_request(
+//!         &Method::GET,
+//!         &"http://upload.qiniup.com/".parse()?,
+//!         &headers,
+//!         &b"{\"name\":\"test\"}"[..],
+//!     );
+//! # Ok(())
+//! # }
+//! ```
+//!
+//! #### 计算下载地址签名
+//!
+//! ```
+//! use qiniu_credential::{Credential, prelude::*};
+//! use std::time::Duration;
+//! # fn main() -> anyhow::Result<()> {
+//! let credential = Credential::new("abcdefghklmnopq", "1234567890");
+//! let url = "http://www.qiniu.com/?go=1".parse()?;
+//! let url = credential
+//!     .get(Default::default())?
+//!     .sign_download_url(url, Duration::from_secs(1_234_567_890 + 3600));
+//! assert_eq!(
+//!     url.to_string(),
+//!     "http://www.qiniu.com/?go=1&e=1234571490&token=abcdefghklmnopq%3AKjQtlGAkEOhSwtFjJfYtYa2-reE%3D",
+//! );
+//! Ok(())
+//! }
+//! ```
 
 use auto_impl::auto_impl;
 use dyn_clonable::clonable;
@@ -104,7 +167,7 @@ impl Credential {
 
     /// 同时返回认证信息的 AccessKey 和 SecretKey
     #[inline]
-    pub fn into_pair(self) -> (AccessKey, SecretKey) {
+    pub fn split(self) -> (AccessKey, SecretKey) {
         (self.access_key, self.secret_key)
     }
 
@@ -133,6 +196,8 @@ impl Credential {
 
     /// 使用七牛签名算法对输入流数据进行签名
     ///
+    /// 该方法的异步版本为 [`Credential::sign_async_reader`]。
+    ///
     /// 参考[管理凭证的签名算法文档](https://developer.qiniu.com/kodo/manual/1201/access-token)
     ///
     /// ```
@@ -204,6 +269,8 @@ impl Credential {
 
     /// 使用七牛签名算法 V1 对 HTTP 请求（请求体为输入流）进行签名，返回 Authorization 的值
     ///
+    /// 该方法的异步版本为 [`Credential::authorization_v1_for_request_with_async_body_reader`]。
+    ///
     /// ```
     /// use qiniu_credential::{Credential, HeaderValue, prelude::*};
     /// use std::io::Cursor;
@@ -258,6 +325,8 @@ impl Credential {
 
     /// 使用七牛签名算法 V2 对 HTTP 请求（请求体为输入流）进行签名，返回 Authorization 的值
     ///
+    /// 该方法的异步版本为 [`Credential::authorization_v2_for_request_with_async_body_reader`]。
+    ///
     /// ```
     /// use qiniu_credential::{Credential, Method, HeaderMap, HeaderValue, prelude::*};
     /// use http::header::CONTENT_TYPE;
@@ -669,6 +738,8 @@ type AsyncIoResult<'a, T> = Pin<Box<dyn Future<Output = IoResult<T>> + 'a + Send
 #[auto_impl(&, &mut, Box, Rc, Arc)]
 pub trait CredentialProvider: Clone + Debug + Sync + Send {
     /// 返回七牛认证信息
+    ///
+    /// 该方法的异步版本为 [`Self::async_get`]。
     fn get(&self, opts: GetOptions) -> IoResult<GotCredential>;
 
     /// 异步返回七牛认证信息
